from typing import List, Optional, Dict

QQ_GROUP_ID_LIST: Optional[Dict[str, List[str]]] = {}
QQ_GUILD_ID_LIST: Optional[Dict[str, List[str]]] = {}

ONEBOT_GROUP_ID_LIST: Optional[Dict[str, List[str]]] = {}
ONEBOT_GUILD_ID_LIST: Optional[Dict[str, List[str]]] = {}



import json
from typing import Union, Optional, Tuple, List

from nonebot.adapters.minecraft import (
    Message,
    TextColor,
    ClickEvent,
    HoverEvent,
    HoverAction,
    ClickAction,
    RconSendBody,
    BaseComponent,
    RconHoverEvent,
    MessageSegment,
    RconClickEvent,
    RconTextComponent,
    ChatImageModComponent
)
from nonebot.adapters.onebot.v11 import Bot as OneBot, GroupMessageEvent as OneBotGroupMessageEvent
from nonebot.adapters.qq import (
    Bot as QQBot,
    GuildMessageEvent as QQGuildMessageEvent,
    GroupAtMessageCreateEvent as QQGroupAtMessageCreateEvent,
)
from nonebot_plugin_guild_patch import GuildMessageEvent as OneBotGuildMessageEvent

from .config import plugin_config


async def __get_group_or_nick_name(
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent, QQGroupAtMessageCreateEvent, OneBotGroupMessageEvent, OneBotGuildMessageEvent
        ],
        user_id: Optional[str] = None
) -> str:
    """
    获取群昵称或者昵称
    :param bot: 平台Bot实例
    :param event: 事件
    :param user_id: 用户ID
    :return: 昵称
    """
    temp_text = "未知昵称" if user_id is None else "[未知群聊]"
    if isinstance(event, OneBotGroupMessageEvent) and isinstance(bot, OneBot):
        if user_id:
            if event.user_id == int(user_id):
                # 如果群名片为空，则发送昵称
                temp_text = event.sender.card or event.sender.nickname
                # 如果获取其他人的昵称
            else:
                temp_text = (
                    await bot.get_group_member_info(group_id=event.group_id, user_id=int(user_id), no_cache=True)
                )["nickname"]
        else:
            temp_text = f'[{(await bot.get_group_info(group_id=event.group_id))["group_name"]}]'

    elif isinstance(event, OneBotGuildMessageEvent) and isinstance(bot, OneBot):
        if user_id:
            if event.user_id == user_id:
                temp_text = event.sender.nickname
            else:
                temp_text = (
                    await bot.get_guild_member_profile(guild_id=event.guild_id, user_id=user_id)
                )["nickname"]
        else:
            temp_text = ""
            if plugin_config.mc_qq_send_guild_name:
                guild_name = (await bot.get_guild_meta_by_guest(guild_id=event.guild_id))["guild_name"]
                temp_text = f"[{guild_name}]"
            if plugin_config.mc_qq_send_channel_name:
                for per_channel in await bot.get_guild_channel_list(
                        guild_id=event.guild_id, no_cache=True
                ):
                    if str(event.channel_id) == per_channel["channel_id"]:
                        channel_name = per_channel["channel_name"]

                        if plugin_config.mc_qq_send_guild_name:
                            temp_text = temp_text.replace("]", f"丨{channel_name}]")
                        else:
                            temp_text = f"[{channel_name}]"
                        break
    elif isinstance(event, QQGuildMessageEvent) and isinstance(bot, QQBot):
        if user_id:
            if event.author.id == user_id:
                temp_text = event.member.nick or event.author.username
            else:
                member = await bot.get_member(guild_id=event.guild_id, user_id=user_id)
                temp_text = member.nick or member.user.username
        else:
            temp_text = ""
            if plugin_config.mc_qq_send_guild_name:
                guild = await bot.get_guild(guild_id=event.guild_id)
                temp_text = f"[{guild.name}]"
            if plugin_config.mc_qq_send_channel_name:
                channel = await bot.get_channel(channel_id=event.channel_id)
                if plugin_config.mc_qq_send_guild_name:
                    temp_text = temp_text.replace("]", f"丨{channel.name}]")
                else:
                    temp_text = f"[{channel.name}]"
    elif isinstance(event, QQGroupAtMessageCreateEvent) and isinstance(bot, QQBot):
        # TODO 等待QQ机器人完善API
        temp_text = event.author.member_openid if user_id else event.group_openid
    return temp_text


def __get_hover_event_component(temp_text):
    """
    获取HoverEvent组件
    :param temp_text:
    :return:
    """
    return HoverEvent(
        action=HoverAction.SHOW_TEXT,
        contents=[BaseComponent(text=temp_text)]
    )


def __get_click_event_component(img_url):
    """
    获取ClickEvent组件
    :param img_url:
    :return:
    """
    return ClickEvent(
        action=ClickAction.OPEN_URL,
        value=img_url
    )


def __get_action_event_component(rcon_mode: bool, img_url: str, temp_text: str, color: TextColor = TextColor.WHITE):
    """
    获取HoverEvent和ClickEvent组件
    :param rcon_mode:
    :param img_url:
    :param temp_text:
    :param color:
    :return:
    """
    hover_event = None
    click_event = None
    if rcon_mode:
        if plugin_config.mc_qq_rcon_hover_event_enable:
            hover_event = __get_rcon_hover_event_component(temp_text.replace("[", "[查看"), color)
        if plugin_config.mc_qq_rcon_click_action_enable:
            click_event = __get_rcon_click_event_component(img_url)
    else:
        hover_event = __get_hover_event_component(temp_text)
        click_event = __get_click_event_component(img_url)
    return hover_event, click_event


async def __get_common_qq_msg_parsing(
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent, QQGroupAtMessageCreateEvent, OneBotGroupMessageEvent, OneBotGuildMessageEvent],
        rcon_mode: bool = False
) -> Tuple[List[Union[str, Message]], str]:
    """
    获取QQ消息解析后的消息列表和日志文本
    :param bot: Bot对象
    :param event: 事件对象
    :param rcon_mode: 是否为RCON模式
    :return: 消息列表和日志文本
    """
    log_text = ""

    message_list = []

    # 消息内容
    for msg in event.get_message():
        click_event = None
        hover_event = None
        temp_color = TextColor.WHITE
        if msg.type == "text":
            temp_text = msg.data["text"].replace("\r", "").replace("\n", "\n * ")

        elif msg.type in ["image", "attachment"]:
            temp_text = "[图片]"
            temp_color = TextColor.AQUA
            img_url = msg.data["url"] if msg.data["url"].startswith("http") else f"https://{msg.data['url']}"
            if plugin_config.mc_qq_chat_image_enable and msg.type in ["image", "attachment"]:
                temp_text = str(ChatImageModComponent(url=img_url, name=temp_text))
            else:
                hover_event, click_event = __get_action_event_component(rcon_mode, img_url, temp_text, TextColor.BLUE)
        elif msg.type == "video":
            temp_text = "[视频]"
            temp_color = TextColor.LIGHT_PURPLE
            img_url = msg.data["url"] if msg.data["url"].startswith("http") else f"https://{msg.data['url']}"
            hover_event, click_event = __get_action_event_component(rcon_mode, img_url, temp_text,
                                                                    TextColor.DARK_PURPLE)
        elif msg.type == "share":
            temp_text = "[分享]"
            temp_color = TextColor.GOLD
            img_url = msg.data["url"] if msg.data["url"].startswith("http") else f"https://{msg.data['url']}"
            hover_event, click_event = __get_action_event_component(rcon_mode, img_url, temp_text, TextColor.YELLOW)

        # @用户 OneBot
        elif msg.type == "at":
            temp_text = f"@{await __get_group_or_nick_name(bot, event, msg.data['qq'])} "
            temp_color = TextColor.GREEN

        # @用户 QQ
        elif msg.type == "mention_user":
            temp_text = (
                f"@{await __get_group_or_nick_name(bot, event, msg.data['user_id'])} "
            )
            temp_color = TextColor.GREEN

        # @子频道
        elif msg.type == "mention_channel":
            temp_text = f"@{(await bot.get_channel(channel_id=event.channel_id)).name} "
            temp_color = TextColor.GREEN

        # @全体成员
        elif msg.type in ["mention_everyone", "all"]:
            temp_text = "@全体成员"
            temp_color = TextColor.GREEN

        elif msg.type in ["face", "emoji"]:
            temp_text = "[表情]"
            temp_color = TextColor.GREEN

        elif msg.type == "record":
            temp_text = "[语音]"
            temp_color = TextColor.GOLD
        else:
            temp_text = "[未知消息类型]"

        # 消息内容
        temp_component = RconTextComponent(
            text=temp_text,
            color=temp_color,
            hover_event=hover_event,
            click_event=click_event
        ) if rcon_mode else MessageSegment.text(
            text=temp_text,
            color=temp_color,
            hover_event=hover_event,
            click_event=click_event
        )

        log_text += temp_text
        if plugin_config.mc_qq_rcon_text_component_status == 2:
            message_list.append(temp_component.get_component().removeprefix('"').removesuffix('"'))
        elif rcon_mode:
            message_list.append(str(temp_component))
        else:
            message_list.append(temp_component)

    return message_list, log_text


async def parse_qq_msg_to_base_model(
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent,
            QQGroupAtMessageCreateEvent,
            OneBotGroupMessageEvent,
            OneBotGuildMessageEvent
        ]
) -> Tuple[Message, str]:
    """
    解析 QQ 消息，转为 WebSocketBody 模型
    :param bot: 聊天平台Bot实例
    :param event: 所有事件
    :return: Message
    """

    message_list = Message(MessageSegment.text(text="[MC_QQ] ", color=TextColor.YELLOW))

    # 是否发送群聊名称
    if plugin_config.mc_qq_send_group_name or (
            plugin_config.mc_qq_send_guild_name or plugin_config.mc_qq_send_channel_name
    ):
        temp_group_name = await __get_group_or_nick_name(bot, event)
        message_list.append(MessageSegment.text(text=f"{temp_group_name} ", color=TextColor.GREEN))

    # 消息发送者昵称
    sender_nickname_text = await __get_group_or_nick_name(bot, event, str(event.get_user_id()))
    message_list.append(MessageSegment.text(text=f"{sender_nickname_text} ", color=TextColor.GREEN))

    # 消息 '说：'
    message_list.append(MessageSegment.text(text="说：", color=TextColor.WHITE))

    # 消息内容
    temp_message_list, log_text = await __get_common_qq_msg_parsing(bot, event, False)

    message_list += Message(temp_message_list)

    return message_list, log_text


def __get_rcon_hover_event_component(text: str, color: TextColor = TextColor.GOLD) -> RconHoverEvent:
    """
    获取 Rcon HoverEvent
    :param text: 悬浮文本
    :param color: 文本颜色
    :return: 悬浮组件
    """
    return RconHoverEvent(
        action=HoverAction.SHOW_TEXT,
        contents=[RconTextComponent(text=text, color=color)],
    )


def __get_rcon_click_event_component(url: str) -> RconClickEvent:
    """
    获取 Rcon ClickEvent
    :param url:
    :return:
    """
    return RconClickEvent(
        action=ClickAction.OPEN_URL,
        url=url
    )


async def parse_qq_msg_to_rcon_model(
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent,
            QQGroupAtMessageCreateEvent,
            OneBotGroupMessageEvent,
            OneBotGuildMessageEvent
        ]
):
    """
    解析 QQ 消息，转为 Rcon命令 模型
    :param bot: bot 对象
    :param event: 事件
    :return: RconSendBody
    """
    rcon_send_body = RconSendBody()
    prefix_component = "[MC_QQ] " if plugin_config.mc_qq_rcon_text_component_status == 0 else RconTextComponent(
        text="[MC_QQ] ", color=TextColor.YELLOW).get_component().removeprefix('"').removesuffix('"')
    log_text = "[MC_QQ] "

    message_list = ["", prefix_component]

    # 是否发送群聊名称
    if plugin_config.mc_qq_send_group_name or (
            plugin_config.mc_qq_send_guild_name or plugin_config.mc_qq_send_channel_name
    ):
        temp_group_name = await __get_group_or_nick_name(bot=bot, event=event)

        group_name_component = RconTextComponent(
            text=temp_group_name, color=TextColor.GREEN
        ) if plugin_config.mc_qq_rcon_text_component_status == 0 else temp_group_name

        message_list.append(group_name_component.get_component().removeprefix('"').removesuffix('"'))
        log_text += str(group_name_component)

    # 发送者昵称
    sender_nickname_text = await __get_group_or_nick_name(bot=bot, event=event, user_id=event.get_user_id())
    log_text += sender_nickname_text
    if plugin_config.mc_qq_rcon_text_component_status == 2:
        sender_nickname_component = RconTextComponent(
            text=sender_nickname_text, color=TextColor.GREEN
        )

        message_list.append(sender_nickname_component.get_component().removeprefix('"').removesuffix('"'))
    else:
        sender_nickname_component = sender_nickname_text

    # 说
    message_list.append("说：")
    log_text += "说："

    rcon_send_body.message = message_list
    # 消息内容
    message_body = RconSendBody()
    temp_message_list, log_msgs = await __get_common_qq_msg_parsing(bot=bot, event=event, rcon_mode=True)
    log_text += log_msgs

    message_body.message = temp_message_list

    result = message_list + temp_message_list

    parsed_result = [json.loads(item) if item.startswith('{') else item for item in result]
    return str(parsed_result), log_text


def parse_qq_screen_cmd_to_rcon_model(
        command_type: str,
        command: str
):
    """
    解析 QQ 消息，转为 Rcon命令 模型
    :param command_type: 命令类型
    :param command: 命令内容
    :return: 命令文本
    """
    if command_type == "action_bar":
        return f'title @a actionbar "{command}"'
    else:
        return f'title @a "{command}"'


def parse_qq_screen_cmd_to_base_model(
        command_type: str,
        command: str
):
    """
    解析 QQ 消息，转为 websocket消息 模型
    :param command_type: 命令类型
    :param command: 命令内容
    :return: 命令文本
    """
    if command_type == "action_bar":
        return Message(MessageSegment.actionbar(text=f"[MC_QQ] {command}", color=TextColor.YELLOW))
    elif command_type == "title":
        title, subtitle = command.split("\n") if "\n" in command else (command, "")
        return Message(MessageSegment.title(title=title, subtitle=subtitle))
    else:
        return Message(MessageSegment.text(text=f"[MC_QQ] {command}", color=TextColor.YELLOW))


__all__ = [
    "parse_qq_msg_to_rcon_model",
    "parse_qq_msg_to_base_model",
    "parse_qq_screen_cmd_to_rcon_model",
    "parse_qq_screen_cmd_to_base_model"
]



from nonebot import logger, get_bots
from nonebot.adapters.onebot.v11 import Bot as OneBot
from nonebot.adapters.qq import Bot as QQBot, AuditException

from .config import plugin_config


async def send_mc_msg_to_qq(server_name: str, msg_result: str):
    if server := plugin_config.mc_qq_server_dict.get(server_name):
        if plugin_config.mc_qq_display_server_name:
            msg_result = f"[{server_name}] {msg_result}"

        for group in server.group_list:
            if bot := get_bots().get(group.bot_id):
                if group.adapter == "onebot":
                    bot: OneBot
                    await bot.send_group_msg(group_id=int(group.group_id), message=msg_result)
                elif group.adapter == "qq":
                    bot: QQBot
                    # TODO: 未实现，一个月主动就四条，还是算了吧。
                    # await bot.send_to_c2c(openid=group.group_id, message=msg_result)
                    logger.debug(f"[MC_QQ]丨未实现的适配器: {group.adapter}，发送至群聊 {group.group_id}失败：一个月主动就四条，还是算了吧。")
                else:
                    logger.error(f"[MC_QQ]丨未知的适配器: {group.adapter}")

        for guild in server.guild_list:
            if bot := get_bots().get(guild.bot_id):
                if guild.adapter == "onebot":
                    bot: OneBot
                    await bot.send_guild_channel_msg(
                        guild_id=guild.guild_id,
                        channel_id=guild.channel_id,
                        message=msg_result
                    )
                elif guild.adapter == "qq":
                    try:
                        bot: QQBot
                        await bot.send_to_channel(channel_id=guild.channel_id, message=msg_result)
                    except AuditException as e:
                        logger.debug(f"[MC_QQ]丨发送至子频道 {guild.channel_id} 的消息：{msg_result} 正在审核中")
                        audit_result = await e.get_audit_result(3)
                        logger.debug(f"[MC_QQ]丨审核结果：{audit_result.get_event_name()}")
    else:
        logger.error(f"未知的服务器: {server_name}")


__all__ = [
    "send_mc_msg_to_qq"
]



from typing import Union, List, Callable, Awaitable, Optional

from nonebot import get_bot, logger
from nonebot.adapters.minecraft import Bot
from nonebot.adapters.onebot.v11 import Bot as OneBot, GroupMessageEvent as OneBotGroupMessageEvent
from nonebot.adapters.qq import (
    Bot as QQBot,
    GuildMessageEvent as QQGuildMessageEvent,
    GroupAtMessageCreateEvent as QQGroupAtMessageCreateEvent,
)
from nonebot.internal.matcher import Matcher
from nonebot_plugin_guild_patch import GuildMessageEvent as OneBotGuildMessageEvent

from .model import (
    ONEBOT_GUILD_ID_LIST,
    ONEBOT_GROUP_ID_LIST,
    QQ_GUILD_ID_LIST,
    QQ_GROUP_ID_LIST
)
from .parse_qq_msg import (
    parse_qq_msg_to_base_model,
    parse_qq_msg_to_rcon_model,
    parse_qq_screen_cmd_to_rcon_model
)
from .config import plugin_config


def __get_mc_bot(server_name: str) -> Union[Bot, None]:
    """
    获取服务器 Bot
    :param server_name: 服务器名称
    :return: 服务器 Bot
    """
    try:
        return get_bot(server_name)
    except KeyError:
        logger.warning(f"[MC_QQ]丨未找到服务器 {server_name} 的 Bot")
    except ValueError:
        logger.warning(f"[MC_QQ]丨{server_name} 无可用 Bot")
    return None


def __get_server_list_by_event(func: Callable[..., Awaitable]) -> Callable:
    """
    通过事件获取服务器列表
    :param func: 发送 rcon cmd 至目标服务器的函数
    :return: 装饰后的发送函数
    """

    async def event_check(
            matcher: Matcher,
            bot: Union[QQBot, OneBot],
            event: Union[
                QQGuildMessageEvent, QQGroupAtMessageCreateEvent, OneBotGroupMessageEvent, OneBotGuildMessageEvent
            ],
            command_type: Optional[str] = "",
            is_cmd: bool = False,
            command: Optional[str] = "",
    ) -> str:
        temp_result = "返回结果：\n"
        if isinstance(event, QQGroupAtMessageCreateEvent):
            server_list = QQ_GROUP_ID_LIST.get(event.group_id)
            temp_result = "\n返回结果：\n"
        elif isinstance(event, QQGuildMessageEvent):
            server_list = QQ_GUILD_ID_LIST.get(event.channel_id)
        elif isinstance(event, OneBotGroupMessageEvent):
            server_list = ONEBOT_GROUP_ID_LIST.get(str(event.group_id))
        else:
            server_list = ONEBOT_GUILD_ID_LIST.get(f"{event.guild_id}:{event.channel_id}")
        return await func(
            matcher=matcher,
            server_list=server_list,
            bot=bot,
            event=event,
            is_cmd=is_cmd,
            command_type=command_type,
            command=command,
            temp_result=temp_result
        )

    return event_check


def __inject_server_list(func: Callable[..., Awaitable[str]]) -> Callable:
    """
    检查服务器列表是否为空
    :param func: 发送 rcon cmd 至目标服务器的函数
    :return: 装饰后的发送函数
    """

    @__get_server_list_by_event
    async def wrapper(
            matcher: Matcher,
            server_list: Optional[List[str]],
            bot: Union[QQBot, OneBot],
            event: Union[
                QQGuildMessageEvent, QQGroupAtMessageCreateEvent, OneBotGroupMessageEvent, OneBotGuildMessageEvent
            ],
            is_cmd: bool,
            command_type: Optional[str],
            command: Optional[str],
            temp_result: str,
    ):
        if server_list:
            return await func(
                server_list=server_list,
                bot=bot,
                event=event,
                is_cmd=is_cmd,
                command=command,
                command_type=command_type,
                temp_result=temp_result
            )
        elif is_cmd:
            return await matcher.finish("该群聊没有对应的服务器，无法发送")
        else:
            return

    return wrapper


@__inject_server_list
async def __send_common_to_target_server(
        server_list: Optional[List[str]],
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent, QQGroupAtMessageCreateEvent, OneBotGroupMessageEvent, OneBotGuildMessageEvent
        ],
        is_cmd: bool,
        command_type: Optional[str],
        command: Optional[str],
        temp_result: str
) -> str:
    """
    发送命令到目标服务器
    :param is_cmd: 是否为命令
    :param server_list: 服务器列表
    :param command: 命令
    :param temp_result: 临时结果
    :return: 去除末尾换行符的结果
    """
    for server_name in server_list:
        if mc_bot := __get_mc_bot(server_name):
            server_config = plugin_config.mc_qq_server_dict.get(server_name)

            send_temp_result = f"发送至服务器：{server_name} "

            if is_cmd:
                send_temp_result += f"命令：{command} "

                if server_config.rcon_cmd and mc_bot.rcon:
                    if command_type == "title":
                        title, subtitle = command.split("\n") if "\n" in command else (command, "")
                        title_result = (await mc_bot.rcon.send_cmd(title))[0]
                        if subtitle:
                            title_result += (await mc_bot.rcon.send_cmd(subtitle))[0]
                        send_temp_result += f"结果：{title_result}"
                    else:
                        cmd = parse_qq_screen_cmd_to_rcon_model(command_type, command)
                        response = await mc_bot.rcon.send_cmd(cmd)
                        send_temp_result += f"结果：{response[0]}\n"
                elif server_config.rcon_cmd and not mc_bot.rcon:
                    send_temp_result += "选择了Rcon发送命令，但无rcon可用，无法发送命令\n"
                else:
                    if command_type == "title":
                        title, subtitle = command.split("\n") if "\n" in command else (command, "")
                        await mc_bot.send_title(title=title, subtitle=subtitle)
                    elif command_type == "action_bar":
                        await mc_bot.send_actionbar(message=command)
                    else:
                        await mc_bot.send_msg(message=command)
                    send_temp_result += "结果：成功\n"

            else:
                send_temp_result += "消息："

                if server_config.rcon_msg and mc_bot.rcon:
                    msg, text = await parse_qq_msg_to_rcon_model(bot=bot, event=event)
                    msg = msg.replace("'", '"')
                    send_temp_result += f"{text} "
                    response = await mc_bot.rcon.send_cmd(f'tellraw @a {msg}')
                    send_temp_result += f"结果：{response[0]}\n"

                elif server_config.rcon_msg and not mc_bot.rcon:
                    send_temp_result += f"选择了Rcon发送消息，但无rcon未开启，无法发送消息\n"

                else:
                    msg, text = await parse_qq_msg_to_base_model(bot=bot, event=event)
                    send_temp_result += f"{text}\n"
                    await mc_bot.send_msg(message=msg)

            temp_result += send_temp_result

        else:
            temp_result += f"{server_name}：未找到服务器 Bot\n"

    temp_result = temp_result.removesuffix("\n")
    logger.debug(f'[MC_QQ]丨{temp_result}')

    return temp_result if is_cmd else ""


async def send_command_to_target_server(
        matcher: Matcher,
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent,
            QQGroupAtMessageCreateEvent,
            OneBotGroupMessageEvent,
            OneBotGuildMessageEvent
        ],
        command: str
):
    """
    发送命令到目标服务器
    :param matcher: 命令匹配器
    :param bot: Bot对象
    :param event: 事件
    :param command: 命令
    :return: 去除末尾换行符的结果
    """
    return await __send_common_to_target_server(
        matcher=matcher,
        bot=bot,
        event=event,
        is_cmd=True,
        command_type="command",
        command=command
    )


async def send_action_bar_to_target_server(
        matcher: Matcher,
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent, QQGroupAtMessageCreateEvent, OneBotGroupMessageEvent, OneBotGuildMessageEvent
        ],
        action_bar
):
    """
    发送actionbar到目标服务器
    :param matcher: 命令匹配器
    :param bot: Bot对象
    :param event: 事件
    :param action_bar: actionbar
    :return: 去除末尾换行符的结果
    """
    return await __send_common_to_target_server(
        matcher=matcher,
        bot=bot,
        event=event,
        is_cmd=True,
        command_type="action_bar",
        command=action_bar
    )


async def send_title_to_target_server(
        matcher: Matcher,
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent, QQGroupAtMessageCreateEvent, OneBotGroupMessageEvent, OneBotGuildMessageEvent
        ],
        arg: str,
):
    """
    发送title到目标服务器
    :param matcher: 命令匹配器
    :param bot: Bot对象
    :param event: 事件
    :param arg: title
    :return: 去除末尾换行符的结果
    """
    return await __send_common_to_target_server(
        matcher=matcher,
        bot=bot,
        event=event,
        is_cmd=True,
        command_type="title",
        command=arg
    )


async def send_message_to_target_server(
        matcher: Matcher,
        bot: Union[QQBot, OneBot],
        event: Union[
            QQGuildMessageEvent,
            QQGroupAtMessageCreateEvent,
            OneBotGroupMessageEvent,
            OneBotGuildMessageEvent
        ]
):
    """
    发送消息到目标服务器
    :param matcher: 命令匹配器
    :param bot: Bot对象
    :param event: 事件
    :return: 去除末尾换行符的结果
    """
    return await __send_common_to_target_server(
        matcher=matcher,
        bot=bot,
        event=event,
        is_cmd=False,
    )


__all__ = [
    "send_title_to_target_server",
    "send_command_to_target_server",
    "send_message_to_target_server",
    "send_action_bar_to_target_server",
]



"""
配置文件
"""

from typing import Optional, List, Dict

from nonebot import get_driver
from pydantic import BaseModel, Extra, Field


class Guild(BaseModel):
    """频道配置"""
    # 频道ID，QQ适配器不需要频道ID
    guild_id: Optional[str] = None
    # 子频道ID
    channel_id: str
    # 适配器类型
    adapter: Optional[str] = None
    # Bot ID 优先使用所选Bot发送消息
    bot_id: Optional[str] = None


class Group(BaseModel):
    """群配置"""
    # 群ID
    group_id: str
    # 适配器类型
    adapter: Optional[str] = None
    # Bot ID
    bot_id: Optional[str] = None


class Server(BaseModel):
    """服务器配置"""
    # 服务器群列表
    group_list: Optional[List[Group]] = []
    # 服务器频道列表
    guild_list: Optional[List[Guild]] = []
    # 是否开启 Rcon 消息
    rcon_msg: Optional[bool] = False
    # 是否开启 Rcon 命令
    rcon_cmd: Optional[bool] = False


class Config(BaseModel, extra=Extra.ignore):
    """配置"""
    # 是否发送群聊名称
    mc_qq_send_group_name: Optional[bool] = False
    # 是否发送频道名称
    mc_qq_send_guild_name: Optional[bool] = False
    # 是否发送子频道名称
    mc_qq_send_channel_name: Optional[bool] = False
    # 是否显示服务器名称
    mc_qq_display_server_name: Optional[bool] = False
    # 服务器列表字典
    mc_qq_server_dict: Optional[Dict[str, Server]] = Field(default_factory=dict)
    # MC_QQ 频道管理员身份组
    mc_qq_guild_admin_roles: Optional[List[str]] = ["频道主", "超级管理员"]
    # MC_QQ 启用 ChatImage MOD
    mc_qq_chat_image_enable: Optional[bool] = False
    # MC_QQ Rcon 启用 ClickAction
    mc_qq_rcon_click_action_enable: Optional[bool] = False
    # MC_QQ Rcon 启用 HoverEvent
    mc_qq_rcon_hover_event_enable: Optional[bool] = False
    # MC_QQ Rcon TextComponent 启用状态
    mc_qq_rcon_text_component_status: Optional[int] = 1
    # MC_QQ 命令白名单
    mc_qq_cmd_whitelist: Optional[List[str]] = ["list", "tps", "banlist"]


plugin_config: Config = Config.parse_obj(get_driver().config)

__all__ = [
    "Group",
    "Guild",
    "Server",
    "Config",
    "plugin_config",
]



import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setuptools.setup(
    name="mcqq-tool",
    version="1.0.7",
    author="17TheWord",
    author_email="17theword@gmail.com",
    description="MC_QQ 工具包",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/17TheWord/mcqq-tool",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Operating System :: OS Independent"
    ]
)
